The branch, master has been updated
       via  aec07b8 s3:smbd:open: Skip redundant call to file_set_dosmode when 
creating a new file.
      from  8247d93 loadparm: Fix memory leak issue.

https://git.samba.org/?p=samba.git;a=shortlog;h=master


- Log -----------------------------------------------------------------
commit aec07b8b60ff9589a3c84eef6adeca464e6c01f6
Author: Jose A. Rivera <jar...@samba.org>
Date:   Wed Feb 3 20:58:19 2016 -0600

    s3:smbd:open: Skip redundant call to file_set_dosmode when creating a new 
file.
    
    Signed-off-by: Jose A. Rivera <jar...@samba.org>
    Pair-programmed-with: Ira Cooper <i...@samba.org>
    Reviewed-by: Jeremy Allison <j...@samba.org>
    
    Autobuild-User(master): Jeremy Allison <j...@samba.org>
    Autobuild-Date(master): Fri Feb  5 04:37:43 CET 2016 on sn-devel-144

-----------------------------------------------------------------------

Summary of changes:
 source3/smbd/open.c | 4 ++--
 1 file changed, 2 insertions(+), 2 deletions(-)


Changeset truncated at 500 lines:

diff --git a/source3/smbd/open.c b/source3/smbd/open.c
index ed0594b..fa817e4 100644
--- a/source3/smbd/open.c
+++ b/source3/smbd/open.c
@@ -3169,8 +3169,8 @@ static NTSTATUS open_file_ntcreate(connection_struct 
*conn,
        }
 
        if (info != FILE_WAS_OPENED) {
-               /* Files should be initially set as archive */
-               if (lp_map_archive(SNUM(conn)) ||
+               /* Overwritten files should be initially set as archive */
+               if ((info == FILE_WAS_OVERWRITTEN && 
lp_map_archive(SNUM(conn))) ||
                    lp_store_dos_attributes(SNUM(conn))) {
                        if (!posix_open) {
                                if (file_set_dosmode(conn, smb_fname,


-- 
Samba Shared Repository

Reply via email to